@@ -553,6 +553,13 @@ class TaylorMethod(DEMethod.DESolveMethod):
             multiplier *= (x - x_0)
         return y
 
+    @staticmethod
+    def convert(func):
+        x = sy.Symbol('x')
+        y_symb = sy.Symbol('y')
+        y_func = sy.Function('y')(x)
+
+        return func.subs(y_symb, y_func)
 
     def solve(self, f,
               initial_dot: Tuple[float, float],
@@ -562,6 +569,8 @@ class TaylorMethod(DEMethod.DESolveMethod):
         if not isinstance(f, tuple(sy.core.all_classes)):
             raise Exception("Taylor Method supports only sympy objects as given functions")
 
+        f = convert(f)
+
         x_0 = initial_dot[0]
         y_0 = initial_dot[1]
         der_list = self.generate_list_of_trees_of_derivatives(count)
